#! /bin/bash

source config

function has_space {
  [[ "$1" != "${1%[[:space:]]*}" ]] && return 0 || return 1
}

function print_usage_and_exit {
  >&2 echo "USAGE : language_keyword templateName expName [arguments]"
  exit 1
}

MCD=data/conllu.mcd
KEYWORD=$1
EXPNAME=$2

if [ -z "$KEYWORD" ];
then
  >&2 echo "ERROR : missing argument 1 (keyword)"
  print_usage_and_exit
fi

if [ -z "$EXPNAME" ];
then
  >&2 echo "ERROR : missing argument 2 (expName)"
  print_usage_and_exit
fi

shift
shift

if [ "$KEYWORD" = "." ]
then
  KEYWORD=""
fi

TEST=$(find $UD_ROOT*$KEYWORD -type f -name '*test*.conllu')
TESTRAW=$(find $UD_ROOT*$KEYWORD -type f -name '*test*.txt')
DEV=$(find $UD_ROOT*$KEYWORD -type f -name '*dev*.conllu')
DEVRAW=$(find $UD_ROOT*$KEYWORD -type f -name '*dev*.txt')
TRAIN=$(find $UD_ROOT*$KEYWORD -type f -name '*train*.conllu')
TRAINRAW=$(find $UD_ROOT*$KEYWORD -type f -name '*train*.txt')

EVALTARGET=$TEST

if has_space "$EVALTARGET";
then
  >&2 echo "ERROR : more than 1 match with keyword" $KEYWORD
  >&2 echo "TEST : " $EVALTARGET
  print_usage_and_exit
fi

if test ! -f $EVALTARGET;
then
  >&2 echo "ERROR : no target file found with keyword" $KEYWORD
  >&2 echo "$EVALTARGET"
  print_usage_and_exit
fi

EVALCONLL="../scripts/conll18_ud_eval.py"
OUTPUT=$EXPNAME"/predicted_eval.tsv"

macaon decode --model $EXPNAME --mcd $MCD --inputTSV $EVALTARGET $@ > $OUTPUT && $EVALCONLL $EVALTARGET $OUTPUT -v || exit 1

